@@ -1,4 +1,4 @@
-use std::{iter, mem};
+use std::iter;
 use swc_atoms::JsWord;
 use swc_common::{collections::AHashSet, util::take::Take, Mark, Spanned, SyntaxContext, DUMMY_SP};
 use swc_ecma_ast::*;
@@ -37,21 +37,18 @@ impl VisitMut for BrandCheckHandler<'_> {
                         unreachable!()
                     }
                 };
-                match &**right {
-                    Expr::Ident(right) => {
-                        if self.class_name.sym == right.sym
-                            && self.class_name.span.ctxt == right.span.ctxt
-                        {
-                            *e = Expr::Bin(BinExpr {
-                                span: *span,
-                                op: op!("==="),
-                                left: Box::new(Expr::Ident(self.class_name.clone())),
-                                right: Box::new(Expr::Ident(right.clone())),
-                            });
-                            return;
-                        }
+                if let Expr::Ident(right) = &**right {
+                    if self.class_name.sym == right.sym
+                        && self.class_name.span.ctxt == right.span.ctxt
+                    {
+                        *e = Expr::Bin(BinExpr {
+                            span: *span,
+                            op: op!("==="),
+                            left: Box::new(Expr::Ident(self.class_name.clone())),
+                            right: Box::new(Expr::Ident(right.clone())),
+                        });
+                        return;
                     }
-                    _ => {}
                 }
 
                 self.names.insert(n.id.sym.clone());
@@ -101,7 +98,8 @@ pub(super) struct FieldAccessFolder<'a> {
 macro_rules! take_vars {
     ($name:ident, $T:tt) => {
         fn $name(&mut self, f: &mut $T) {
-            assert!(self.vars.is_empty());
+            let old_var = self.vars.take();
+
             if f.body.is_none() {
                 return;
             }
@@ -114,12 +112,14 @@ macro_rules! take_vars {
                     Stmt::Decl(Decl::Var(VarDecl {
                         span: DUMMY_SP,
                         kind: VarDeclKind::Var,
-                        decls: mem::take(&mut self.vars),
+                        decls: self.vars.take(),
 
                         declare: false,
                     })),
                 )
             }
+
+            self.vars = old_var;
         }
     };
 }
@@ -305,10 +305,7 @@ impl<'a> VisitMut for FieldAccessFolder<'a> {
 
                 let var = alias_ident_for(&obj, "_ref");
 
-                let this = if match *obj {
-                    Expr::This(..) => true,
-                    _ => false,
-                } {
+                let this = if matches!(*obj, Expr::This(..)) {
                     ThisExpr { span: DUMMY_SP }.as_arg()
                 } else if *op == op!("=") {
                     obj.as_arg()
@@ -454,19 +451,6 @@ impl<'a> VisitMut for FieldAccessFolder<'a> {
         };
     }
 
-    fn visit_mut_member_expr(&mut self, e: &mut MemberExpr) {
-        e.obj.visit_mut_with(self);
-        if let MemberProp::Computed(c) = &mut e.prop {
-            c.visit_mut_with(self);
-        }
-    }
-
-    fn visit_mut_super_prop_expr(&mut self, e: &mut SuperPropExpr) {
-        if let SuperProp::Computed(c) = &mut e.prop {
-            c.visit_mut_with(self);
-        }
-    }
-
     fn visit_mut_pat(&mut self, p: &mut Pat) {
         if let Pat::Expr(expr) = &p {
             if let Expr::Member(me) = &**expr {
@@ -573,8 +557,7 @@ impl<'a> FieldAccessFolder<'a> {
 
                             type_args: Default::default(),
                         }
-                        .make_member(quote_ident!("value"))
-                        .into(),
+                        .make_member(quote_ident!("value")),
                         Some(Expr::This(*this)),
                     ),
                     _ => unimplemented!("destructuring set for object except this"),
@@ -627,18 +610,16 @@ impl<'a> FieldAccessFolder<'a> {
 
                     let first_arg = if is_alias_initialized {
                         var.clone().as_arg()
-                    } else {
-                        if aliased {
-                            AssignExpr {
-                                span: DUMMY_SP,
-                                left: PatOrExpr::Pat(var.clone().into()),
-                                op: op!("="),
-                                right: obj.take(),
-                            }
-                            .as_arg()
-                        } else {
-                            var.clone().as_arg()
+                    } else if aliased {
+                        AssignExpr {
+                            span: DUMMY_SP,
+                            left: PatOrExpr::Pat(var.clone().into()),
+                            op: op!("="),
+                            right: obj.take(),
                         }
+                        .as_arg()
+                    } else {
+                        var.clone().as_arg()
                     };
 
                     let args = if is_method {
